@@ -8,8 +8,7 @@ this template) with an import statement.
 import importlib
 import os
 
-from ae.base import TESTS_FOLDER                # type: ignore
-from ae.inspector import module_attr            # type: ignore
+from ae.base import TESTS_FOLDER, module_attr                               # type: ignore
 
 
 main_imp_name = "{'main' if os.path.isfile(os.path.join(project_path, 'main' + PY_EXT)) else import_name}"
